==> jc-1.4.0.tar.gz: jas/MethodCP.h <==
// public class jas.MethodCP

// class file dependencies
// @dep_class c0e5264359137f3 jas_CP
// @dep_class b71307c8e3ed573f jas_MethodCP
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header jas_CP

#include "jas/CP.h"

#ifndef _JC_jas_MethodCP_H_
#define _JC_jas_MethodCP_H_

// Forward structure declarations
struct _jc_jas_ClassCP$object;
struct _jc_jas_ClassEnv$object;
struct _jc_jas_NameTypeCP$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_jas_MethodCP$sub_refs	_jc_jas_MethodCP$sub_refs;
typedef struct _jc_jas_MethodCP$sub_nonrefs	_jc_jas_MethodCP$sub_nonrefs;
typedef struct _jc_jas_MethodCP$refs	_jc_jas_MethodCP$refs;
typedef struct _jc_jas_MethodCP$nonrefs	_jc_jas_MethodCP$nonrefs;
typedef struct _jc_jas_MethodCP$object	_jc_jas_MethodCP$object;

typedef const struct _jc_jas_MethodCP$vmethods	_jc_jas_MethodCP$vmethods;
typedef const struct _jc_jas_MethodCP$vtable	_jc_jas_MethodCP$vtable;
typedef const struct _jc_jas_MethodCP$vtype	_jc_jas_MethodCP$vtype;

// Constructors
extern void _jc_jas_MethodCP$method$_init$ab068ddc672b930e(_jc_env *, struct _jc_jas_MethodCP$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern void _jc_jas_MethodCP$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_MethodCP$object *, struct _jc_jas_ClassEnv$object *);
extern void _jc_jas_MethodCP$method$write$c5719140f8114b75(_jc_env *, struct _jc_jas_MethodCP$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_jas_MethodCP$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_MethodCP$method_info$write$c5719140f8114b75;

// Virtual methods structure
struct _jc_jas_MethodCP$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_MethodCP$object *, struct _jc_jas_ClassEnv$object *);
	void	(*write$c5719140f8114b75)(_jc_env *, struct _jc_jas_MethodCP$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *);
};

// Vtable
struct _jc_jas_MethodCP$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_CP$vmethods	jas_CP;
	_jc_jas_MethodCP$vmethods	jas_MethodCP;
};

// Vtype
struct _jc_jas_MethodCP$vtype {
	_jc_type			type;
	_jc_jas_MethodCP$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_MethodCP$sub_refs {
	struct _jc_jas_ClassCP$object	*clazz;
	struct _jc_jas_NameTypeCP$object	*nt;
};

// Reference instance fields (object)
struct _jc_jas_MethodCP$refs {
    _jc_jas_MethodCP$sub_refs	jas_MethodCP;
    _jc_jas_CP$sub_refs	jas_CP;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_MethodCP$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_MethodCP$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_CP$sub_nonrefs	jas_CP;
    _jc_jas_MethodCP$sub_nonrefs	jas_MethodCP;
};

// Object instance structure
struct _jc_jas_MethodCP$object {
	_jc_jas_MethodCP$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_MethodCP$vtype	*vtype;
	_jc_jas_MethodCP$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_MethodCP$vtype _jc_jas_MethodCP$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_MethodCP, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_MethodCP$class_object;

#endif	/* _JC_jas_MethodCP_H_ */

==> jc-1.4.6.tar.gz: jas/MethodCP.h <==
// public class jas.MethodCP

// class file dependencies
// @dep_class c0e5264359137f3 jas_CP
// @dep_class b71307c8e3ed573f jas_MethodCP
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header jas_CP

#include "jas/CP.h"

#ifndef _JC_jas_MethodCP_H_
#define _JC_jas_MethodCP_H_

// Forward structure declarations
struct _jc_jas_ClassCP$object;
struct _jc_jas_ClassEnv$object;
struct _jc_jas_NameTypeCP$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_jas_MethodCP$sub_refs	_jc_jas_MethodCP$sub_refs;
typedef struct _jc_jas_MethodCP$sub_nonrefs	_jc_jas_MethodCP$sub_nonrefs;
typedef struct _jc_jas_MethodCP$refs	_jc_jas_MethodCP$refs;
typedef struct _jc_jas_MethodCP$nonrefs	_jc_jas_MethodCP$nonrefs;
typedef struct _jc_jas_MethodCP$object	_jc_jas_MethodCP$object;

typedef const struct _jc_jas_MethodCP$vmethods	_jc_jas_MethodCP$vmethods;
typedef const struct _jc_jas_MethodCP$vtable	_jc_jas_MethodCP$vtable;
typedef const struct _jc_jas_MethodCP$vtype	_jc_jas_MethodCP$vtype;

// Constructors
extern void _jc_jas_MethodCP$method$_init$ab068ddc672b930e(_jc_env *, struct _jc_jas_MethodCP$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_jas_MethodCP$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_MethodCP$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
extern void _jc_jas_MethodCP$method$write$c5719140f8114b75(_jc_env *, struct _jc_jas_MethodCP$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_jas_MethodCP$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_MethodCP$method_info$write$c5719140f8114b75;

// Virtual methods structure
struct _jc_jas_MethodCP$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_MethodCP$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
	void	(*write$c5719140f8114b75)(_jc_env *, struct _jc_jas_MethodCP$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_jas_MethodCP$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_CP$vmethods	jas_CP;
	_jc_jas_MethodCP$vmethods	jas_MethodCP;
};

// Vtype
struct _jc_jas_MethodCP$vtype {
	_jc_type			type;
	_jc_jas_MethodCP$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_MethodCP$sub_refs {
	struct _jc_jas_ClassCP$object	*clazz;
	struct _jc_jas_NameTypeCP$object	*nt;
};

// Reference instance fields (object)
struct _jc_jas_MethodCP$refs {
    _jc_jas_MethodCP$sub_refs	jas_MethodCP;
    _jc_jas_CP$sub_refs	jas_CP;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_MethodCP$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_MethodCP$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_CP$sub_nonrefs	jas_CP;
    _jc_jas_MethodCP$sub_nonrefs	jas_MethodCP;
};

// Object instance structure
struct _jc_jas_MethodCP$object {
	_jc_jas_MethodCP$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_MethodCP$vtype	*vtype;
	_jc_jas_MethodCP$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_MethodCP$vtype _jc_jas_MethodCP$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_MethodCP, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_MethodCP$class_object;

#endif	/* _JC_jas_MethodCP_H_ */
